Module: Pdfrb::Arlington::Predicate::Functions::ReferencePredicates
- Defined in:
- lib/pdfrb/arlington/predicate/functions/reference.rb
Overview
Reference-shape predicates: MustBeDirect, MustBeIndirect. These are mostly used in the IndirectReference column of TSVs to override the TRUE/FALSE default.
Class Method Summary collapse
Class Method Details
.register_all ⇒ Object
13 14 15 16 17 18 19 20 21 |
# File 'lib/pdfrb/arlington/predicate/functions/reference.rb', line 13 def register_all Functions.register("MustBeDirect") do |_args, _ctx| true # semantically: the field must be a direct object end Functions.register("MustBeIndirect") do |_args, _ctx| true # semantically: the field must be an indirect object end end |