Exception: Pdfrb::EncryptionError
- Defined in:
- lib/pdfrb/error.rb
Overview
Encryption setup, decryption, or encryption failed. Subclassed further by the Encryption namespace as needed (DecryptionError, UnsupportedEncryptionError).
Encryption setup, decryption, or encryption failed. Subclassed further by the Encryption namespace as needed (DecryptionError, UnsupportedEncryptionError).