Class: Pdfrb::Model::Type::CharProcMap
- Inherits:
-
Cos::Dictionary
- Object
- Object
- Cos::Dictionary
- Pdfrb::Model::Type::CharProcMap
- Includes:
- NameMap
- Defined in:
- lib/pdfrb/model/type/font_multiple_master.rb
Overview
CharProcMap (s9.6.4). Mapping from character names to the content-stream procedures that draw them, used by Type 3 fonts. The actual procedures live as streams under their names in a Tiling pattern's Resources.
Instance Attribute Summary
Attributes inherited from Object
Instance Method Summary collapse
Methods included from NameMap
#[], #add, #each_entry, #names
Methods inherited from Cos::Dictionary
#[], #[]=, apply_arlington_definition, arlington_default, arlington_key_to_symbol, arlington_one_type_to_ruby, arlington_required?, arlington_scalar, arlington_types_to_ruby, arlington_version, define_field, define_field_from_arlington, #delete, #each, each_field, #each_raw, #empty?, field, #initialize, #key?, #keys, lookup_type, merged_field, own_fields, #pdf_type, register_type, type_map, #validate
Methods included from Cos::ArlingtonBacked
Methods inherited from Object
#==, define_type, #deref, #indirect?, #initialize, #must_be_indirect?, #pdf_type, pdf_type, #ref
Constructor Details
This class inherits a constructor from Pdfrb::Model::Cos::Dictionary
Instance Method Details
#has_glyph?(char_name) ⇒ Boolean
47 48 49 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 47 def has_glyph?(char_name) !!procedure_for(char_name) end |