Exception: Pdfrb::LexError

Inherits:
ParseError show all
Defined in:
lib/pdfrb/error.rb

Overview

Lexer hit a byte or construct it could not consume (bad hex digit, unterminated string literal, invalid number, etc.).

Instance Attribute Summary

Attributes inherited from ParseError

#source_position

Method Summary

Methods inherited from ParseError

#initialize

Constructor Details

This class inherits a constructor from Pdfrb::ParseError