Class: Pdfrb::Model::Type::CharProcMap
- Inherits:
-
Cos::Dictionary
- Object
- Object
- Cos::Dictionary
- Pdfrb::Model::Type::CharProcMap
- Defined in:
- lib/pdfrb/model/type/font_multiple_master.rb
Overview
CharProcMap (s9.6.4). Mapping from character names to the content-stream procedures that draw them, used by Type 3 fonts. The actual procedures live as streams under their names in a Tiling pattern's Resources.
Instance Attribute Summary
Attributes inherited from Object
Instance Method Summary collapse
- #each_procedure(&block) ⇒ Object
- #entries ⇒ Object
- #has_glyph?(char_name) ⇒ Boolean
- #procedure_for(char_name) ⇒ Object
Methods inherited from Cos::Dictionary
#[], #[]=, apply_arlington_definition, arlington_default, arlington_key_to_symbol, arlington_one_type_to_ruby, arlington_required?, arlington_scalar, arlington_types_to_ruby, arlington_version, define_field, define_field_from_arlington, #delete, #each, each_field, #each_raw, #empty?, field, #initialize, #key?, #keys, lookup_type, merged_field, own_fields, #pdf_type, register_type, type_map, #validate
Methods included from Cos::ArlingtonBacked
Methods inherited from Object
#==, define_type, #deref, #indirect?, #initialize, #must_be_indirect?, #pdf_type, pdf_type
Constructor Details
This class inherits a constructor from Pdfrb::Model::Cos::Dictionary
Instance Method Details
#each_procedure(&block) ⇒ Object
46 47 48 49 50 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 46 def each_procedure(&block) return enum_for(:each_procedure) unless block value.each(&block) end |
#entries ⇒ Object
42 43 44 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 42 def entries value.each end |
#has_glyph?(char_name) ⇒ Boolean
56 57 58 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 56 def has_glyph?(char_name) !!procedure_for(char_name) end |
#procedure_for(char_name) ⇒ Object
52 53 54 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 52 def procedure_for(char_name) value[char_name.to_sym] || value[char_name.to_s] end |