Class: Pdfrb::Model::Type::CharProcMap
- Inherits:
-
Cos::Dictionary
- Object
- Object
- Cos::Dictionary
- Pdfrb::Model::Type::CharProcMap
- Defined in:
- lib/pdfrb/model/type/font_multiple_master.rb
Overview
CharProcMap (s9.6.4). Mapping from character names to the content-stream procedures that draw them, used by Type 3 fonts. The actual procedures live as streams under their names in a Tiling pattern's Resources.
Instance Attribute Summary
Attributes inherited from Object
Instance Method Summary collapse
- #each_procedure(&block) ⇒ Object
- #entries ⇒ Object
- #has_glyph?(char_name) ⇒ Boolean
- #procedure_for(char_name) ⇒ Object
Methods inherited from Cos::Dictionary
#[], #[]=, arlington_available?, arlington_default, arlington_key_to_symbol, arlington_loaded_for?, arlington_mark_loaded, arlington_object, arlington_one_type_to_ruby, arlington_required?, arlington_types_to_ruby, arlington_version, define_field, define_field_from_arlington, #delete, #each, each_field, #each_raw, #empty?, field, #initialize, #key?, #keys, lookup_type, own_fields, #pdf_type, register_type, type_map, #validate
Methods inherited from Object
#==, define_type, #deref, #indirect?, #initialize, #must_be_indirect?, #pdf_type, pdf_type
Constructor Details
This class inherits a constructor from Pdfrb::Model::Cos::Dictionary
Instance Method Details
#each_procedure(&block) ⇒ Object
44 45 46 47 48 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 44 def each_procedure(&block) return enum_for(:each_procedure) unless block value.each(&block) end |
#entries ⇒ Object
40 41 42 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 40 def entries value.each end |
#has_glyph?(char_name) ⇒ Boolean
54 55 56 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 54 def has_glyph?(char_name) !!procedure_for(char_name) end |
#procedure_for(char_name) ⇒ Object
50 51 52 |
# File 'lib/pdfrb/model/type/font_multiple_master.rb', line 50 def procedure_for(char_name) value[char_name.to_sym] || value[char_name.to_s] end |